<?php

class osC_Payment_easypay extends osC_Payment {

    var $_title, $_code = 'easypay', $_status = false, $_sort_order, $_order_id, $_ignore_order_totals = array('sub_total', 'tax', 'total'), $_transaction_response, $pfHost = '';

    function osC_Payment_easypay() {
        global $osC_Database, $osC_Language, $osC_ShoppingCart;
        $this->_title = $osC_Language->get('payment_easypay_title');
        $this->_method_title = $osC_Language->get('payment_easypay_method_title');
        $this->_sort_order = MODULE_PAYMENT_EASYPAY_SORT_ORDER;
        $this->_status = ((MODULE_PAYMENT_EASYPAY_STATUS == '1') ? true : false);

        $this->pfHost = 'ssl.easypay.by/weborder/EP_Module=tomatocart_1_1';
        $this->form_action_url = 'https://' . $this->pfHost;

        if ($this->_status === true) {
            $this->order_status = MODULE_PAYMENT_EASYPAY_ORDER_STATUS_ID > 0 ? (int)
                MODULE_PAYMENT_EASYPAY_ORDER_STATUS_ID : (int) ORDERS_STATUS_PAID;

            if ((int) MODULE_PAYMENT_EASYPAY_ZONE > 0) {
                $check_flag = false;

                $Qcheck = $osC_Database->query('select zone_id from :table_zones_to_geo_zones where geo_zone_id = :geo_zone_id and zone_country_id = :zone_country_id order by zone_id');
                $Qcheck->bindTable(':table_zones_to_geo_zones', TABLE_ZONES_TO_GEO_ZONES);
                $Qcheck->bindInt(':geo_zone_id', MODULE_PAYMENT_EASYPAY_ZONE);
                $Qcheck->bindInt(':zone_country_id', $osC_ShoppingCart->getBillingAddress('country_id'));
                $Qcheck->execute();

                while ($Qcheck->next()) {
                    if ($Qcheck->valueInt('zone_id') < 1) {
                        $check_flag = true;
                        break;
                    } elseif ($Qcheck->valueInt('zone_id') == $osC_ShoppingCart->getBillingAddress('zone_id')) {
                        $check_flag = true;
                        break;
                    }
                }

                if ($check_flag == false) {
                    $this->_status = false;
                }
            }
        }
    }

    function selection() {
        return array('id' => $this->_code, 'module' => $this->_method_title);
    }

    function pre_confirmation_check() {
        global $osC_ShoppingCart;

        $cart_id = $osC_ShoppingCart->getCartID();
        if (empty($cart_id)) {
            $osC_ShoppingCart->generateCartID();
        }
    }

    function confirmation() {
        $this->_order_id = osC_Order::insert(MODULE_PAYMENT_EASYPAY_PROCESSING_ORDER_STATUS_ID); 
    }

    function process_button() {
		global $osC_Customer, $osC_Currencies, $osC_ShoppingCart, $osC_Tax, $osC_Language;

		$process_button_string = '';
		//Получение суммы заказа
		$amount = $osC_Currencies->formatRaw($osC_ShoppingCart->getTotal());
		//Вычесление подписи
		$hash = md5(MODULE_PAYMENT_EASYPAY_MERCHANT_ID . MODULE_PAYMENT_EASYPAY_WEBKEY . $this->_order_id . $amount);
		//Массив с параметрами
		$params = array('EP_MerNo' => MODULE_PAYMENT_EASYPAY_MERCHANT_ID,
						'EP_Sum' => $amount,
						'EP_OrderNo' => $this->_order_id,
						'EP_Expires' => MODULE_PAYMENT_EASYPAY_EXPIRES,
						'EP_Comment' => 'Заказ от магазина ' .STORE_NAME,
						'EP_OrderInfo' => 'Заказ №'.$this->_order_id,
						'EP_Debug' => MODULE_PAYMENT_EASYPAY_DEBUG,
						'EP_Hash' => $hash,
						'EP_Success_URL' =>  HTTPS_SERVER . DIR_WS_HTTPS_CATALOG . FILENAME_CHECKOUT."?callback&module=easypay&result=success",
						'EP_Cancel_URL' => HTTPS_SERVER . DIR_WS_HTTPS_CATALOG . FILENAME_CHECKOUT."?callback&module=easypay&result=fail",
						'EP_Encoding' => 'utf-8',
		);

		//Формирование формы для отправки на weborder
		foreach ($params as $key => $value) {
			$process_button_string .= osc_draw_hidden_field($key, $value);
		}

		$osC_ShoppingCart->reset(true);//Очищение корзины

		return $process_button_string;
       
    }

    /**
     *Функция обработки урлов возврата
     */
    function callback() {
		global $messageStack, $osC_ShoppingCart, $osC_Database, $osC_Currencies;

		$result = $_REQUEST['result'];
		$order_id = $_REQUEST['EP_OrderNo'];

		if($result == 'success'){//Обработка в случае успешной оплаты	
			$message = "<font size='4' color='#00a12d'>Операция оплаты прошла успешно</font>";	
			$messageStack->add_session("shopping_cart", $message, "success");
			osc_redirect(osc_href_link(FILENAME_CHECKOUT, '', 'SSL'));	

		}elseif($result == 'fail'){//Обработка в случае неуспешной оплаты
			$this->order_status = 8;//Статус "Отменен"
			osC_Order::process($order_id, $this->order_status);//Отмена статуса
			$message = "<font size='4' color='#D1001D'>Ошибка оплаты счета</font>";
			$messageStack->add_session('shopping_cart', $message, 'error');
			 osc_redirect(osc_href_link(FILENAME_CHECKOUT, '', 'SSL'));

		}elseif($result == 'notify'){
			$values = array();
			$values['order_mer_code'] = $_REQUEST['order_mer_code'];
			$values['sum'] = $_REQUEST['sum'];
			$values['mer_no'] = $_REQUEST['mer_no'];
			$values['card'] = $_REQUEST['card'];
			$values['purch_date'] = $_REQUEST['purch_date'];
			$values['notify_signature'] = $_REQUEST['notify_signature'];
			$values['web_key'] = MODULE_PAYMENT_EASYPAY_WEBKEY;

			$signature_checked = -1;

			if (($values['order_mer_code'] != '') && 
				($values['sum'] != '') && 
				($values['mer_no'] != '') && 
				($values['card'] != '') && 
				($values['purch_date'] != '')
				){
				$signature_checked = 0;
				$hash = md5($values['order_mer_code'] . 
					$values['sum'] . 
					$values['mer_no'] . 
					$values['card'] . 
					$values['purch_date'] . 
					$values['web_key']);
				if ($hash == $values['notify_signature']){
					$signature_checked = 1;
				}
			}

			if ($signature_checked == 1){
				$this->order_status = MODULE_PAYMENT_EASYPAY_ORDER_STATUS_ID;
				osC_Order::process($values['order_mer_code'], $this->order_status);//Обновление статуса
				header("HTTP/1.0 200 OK");
				print $status = 'OK | the notice is processed'; //Все успешно
			}elseif ($signature_checked == 0){
				header("HTTP/1.0 400 Bad Request");
				print $status = 'FAILED | incorrect digital signature'; //Ошибка вычисления электронной подписи
			}else{
				header("HTTP/1.0 400 Bad Request");
				print $status = 'FAILED | the notice is not processed'; //Ошибка в параметрах
			} 
		}

	}
}
?>
